powered by
Returns a tibble that has year, month, week, week day and hour added from a date column
ts_ymwdh_tbl(.data, .date_col)
The data that is being analyzed, data must be a tibble/data.frame
The column of the tibble that holds the date
A tibble
Supply data with a date column and this will add the year, month, week, week day and hour to the tibble. The original date column is kept.
Returns a tibble.
You must know the data going into the function and if certain columns should be dropped or kept when using further functions
Future work - Add boolean for pad_by_time to fill in missing time series information
# NOT RUN { library(timetk) ts_ymwdh_tbl( .data = m4_daily , .date_col = date ) # }
Run the code above in your browser using DataLab